You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sling.apache.org by ro...@apache.org on 2017/11/07 09:25:50 UTC

[sling-org-apache-sling-discovery-base] 10/16: SLING-5224 : increasing wait time from 100ms to 1000ms to avoid test failure on jenkins

This is an automated email from the ASF dual-hosted git repository.

rombert pushed a commit to annotated tag org.apache.sling.discovery.base-1.0.2
in repository https://gitbox.apache.org/repos/asf/sling-org-apache-sling-discovery-base.git

commit f129180d5c9269cc270cc3927df5f2fa8c0126e7
Author: Stefan Egli <st...@apache.org>
AuthorDate: Mon Nov 2 09:05:28 2015 +0000

    SLING-5224 : increasing wait time from 100ms to 1000ms to avoid test failure on jenkins
    
    git-svn-id: https://svn.apache.org/repos/asf/sling/trunk/bundles/extensions/discovery/base@1711913 13f79535-47bb-0310-9956-ffa450edef68
---
 .../apache/sling/discovery/base/its/AbstractSingleInstanceTest.java   | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/test/java/org/apache/sling/discovery/base/its/AbstractSingleInstanceTest.java b/src/test/java/org/apache/sling/discovery/base/its/AbstractSingleInstanceTest.java
index 324772a..619e76a 100644
--- a/src/test/java/org/apache/sling/discovery/base/its/AbstractSingleInstanceTest.java
+++ b/src/test/java/org/apache/sling/discovery/base/its/AbstractSingleInstanceTest.java
@@ -137,8 +137,8 @@ public abstract class AbstractSingleInstanceTest {
         instance.bindPropertyProvider(pp, propertyName);
 
         instance.heartbeatsAndCheckView();
-        // wait 100ms for the vote to happen
-        Thread.sleep(100);
+        // wait 1000ms for the vote to happen
+        Thread.sleep(1000);
         assertEquals(propertyValue,
                 instance.getClusterViewService().getLocalClusterView()
                         .getInstances().get(0).getProperty(propertyName));

-- 
To stop receiving notification emails like this one, please contact
"commits@sling.apache.org" <co...@sling.apache.org>.